/// <reference types="node" />
/// <reference types="busboy" />
import { EventEmitter } from "events";
import { IncomingMessage } from "http";
import { ParseAsyncResults, TransmitManager, TransmitOptions } from "./transmit.interfaces";
export declare const TRANSMIT_DEFAULT_OPTIONS: TransmitOptions;
export declare class Transmit extends EventEmitter {
    private readonly fields;
    private readonly files;
    private readonly incoming;
    private readonly options;
    private readonly pendingFiles;
    private isAborted;
    private isFinished;
    constructor(options?: Partial<TransmitOptions>);
    /**
     * Whether the upload has been aborted.
     */
    get aborted(): boolean;
    /**
     * Whether the upload has been finished.
     */
    get finished(): boolean;
    /**
     * The transmit manager used for this instance.
     */
    get manager(): TransmitManager;
    /**
     * Abort the current upload. Emits "aborted" and "done" events.
     */
    abort(error?: Error): void;
    /**
     * Delete uploaded files for this request. Useful for cleanup after aborting the upload.
     */
    removeUploadedFiles(): Promise<void>;
    /**
     * Parse an incoming request with form data.
     */
    parse(req: IncomingMessage): busboy.Busboy;
    /**
     * Parse an incoming request with form data and return its fields and files.
     * If the request is aborted, all uploaded files will be deleted.
     */
    parseAsync(req: IncomingMessage): Promise<ParseAsyncResults>;
    private createBusboy;
    private finish;
    private handleIncomingField;
    private handleIncomingFile;
    private writeFile;
}
